public inbox for linux-staging@lists.linux.dev
 help / color / mirror / Atom feed
From: Mingzai Sun <szp2017@gmail.com>
To: forest@alittletooquiet.net, gregkh@linuxfoundation.org
Cc: linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org,
	Mingzai Sun <szp2017@gmail.com>
Subject: [PATCH v2] staging: vt6655: Change camel case variables to snake case
Date: Thu, 10 Aug 2023 22:08:34 +0800	[thread overview]
Message-ID: <20230810140834.5762-1-szp2017@gmail.com> (raw)
In-Reply-To: <20230805035739.376502-1-szp2017@gmail.com>

Remove the unneeded "by" prefix.

Signed-off-by: Mingzai Sun <szp2017@gmail.com>
---
Changes in v2:
  - Change "by_contnt_offset" to "contnt_offset".
---
 drivers/staging/vt6655/srom.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/vt6655/srom.c b/drivers/staging/vt6655/srom.c
index 812964ab68c5..1b89d401a7eb 100644
--- a/drivers/staging/vt6655/srom.c
+++ b/drivers/staging/vt6655/srom.c
@@ -49,7 +49,7 @@
  * Parameters:
  *  In:
  *      iobase          - I/O base address
  *      by_contnt_offset  - address of EEPROM
  *  Out:
  *      none
  *
@@ -57,7 +57,7 @@
  *
  */
 unsigned char SROMbyReadEmbedded(void __iomem *iobase,
-				 unsigned char by_contnt_offset)
+				 unsigned char contnt_offset)
 {
 	unsigned short wDelay, wNoACK;
 	unsigned char byWait;
@@ -70,7 +70,7 @@ unsigned char SROMbyReadEmbedded(void __iomem *iobase,
 	iowrite8(byOrg & (~I2MCFG_NORETRY), iobase + MAC_REG_I2MCFG);
 	for (wNoACK = 0; wNoACK < W_MAX_I2CRETRY; wNoACK++) {
 		iowrite8(EEP_I2C_DEV_ID, iobase + MAC_REG_I2MTGID);
-		iowrite8(by_contnt_offset, iobase + MAC_REG_I2MTGAD);
+		iowrite8(contnt_offset, iobase + MAC_REG_I2MTGAD);
 
 		/* issue read command */
 		iowrite8(I2MCSR_EEMR, iobase + MAC_REG_I2MCSR);
@@ -49,7 +49,7 @@
  *  In:
  *      iobase          - I/O base address
- *      by_contnt_offset  - address of EEPROM
+ *      contnt_offset  - address of EEPROM
  *  Out:
  *      none
-- 
2.34.1


  parent reply	other threads:[~2023-08-10 14:08 UTC|newest]

Thread overview: 5+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-08-05  3:57 [PATCH] staging: vt6655: Change camel case variables to snake case Mingzai Sun
2023-08-09 12:21 ` Greg KH
2023-08-10 14:00   ` Leo Sun
2023-08-10 14:08 ` Mingzai Sun [this message]
2023-08-11 20:36   ` [PATCH v2] " Greg KH

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230810140834.5762-1-szp2017@gmail.com \
    --to=szp2017@gmail.com \
    --cc=forest@alittletooquiet.net \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox